@@ -7,8 +7,8 @@ import requests
 
 from requests.exceptions import ReadTimeout
 
-from gevault.vault import Vault
-from gevault.admin import MOUNT_POINT, SIGNING_ROLE
+from gevault.lib.vault import Vault
+from gevault.lib.admin import MOUNT_POINT, SIGNING_ROLE
 
 DEFAULT_KEY_NAME = "vault"
 DEFAULT_VAULT_VARIABLE = "VAULT_TOKEN"
